@@ -58,9 +58,7 @@
 
 #include "drag_pixmap.xpm"
 
-#ifndef RRD_BASEDIR
-#define RRD_BASEDIR "/var/lib/collectd/rrd"
-#endif
+#include "../config.h"
 
 #define I18N_NOOP(text) text
 
@@ -248,7 +246,7 @@ static void get_rrds(const boost::filesystem::path rrdpath,
  * @param parent parent-widget see KMainWindow
  */
 KCollectdGui::KCollectdGui(QWidget *parent)
-    : KMainWindow(parent), action_collection(parent) {
+    : KMainWindow(parent), action_collection(parent), rrdbasedir() {
   // standard_actions
   for (size_t i = 0; i < sizeof(standard_actions) / sizeof(*standard_actions);
        ++i)
@@ -369,9 +367,6 @@ KCollectdGui::KCollectdGui(QWidget *parent)
   viewMenu->addAction(actionCollection()->action("hideTree"));
 
   menuBar()->addMenu(helpMenu());
-
-  // build rrd-tree
-  get_rrds(RRD_BASEDIR, listview());
 }
 
 KCollectdGui::~KCollectdGui() {}
@@ -402,6 +397,15 @@ void KCollectdGui::set(Graph *new_graph) {
   vbox->insertWidget(0, new_graph);
 }
 
+void KCollectdGui::setRRDBaseDir(const QString &newrrdbasedir) {
+  if (rrdbasedir.isEmpty()) {
+    rrdbasedir = QString(newrrdbasedir);
+    // build rrd-tree
+    get_rrds(rrdbasedir.toStdString(), listview());
+  } 
+  // XXX: silently fail on new unimplemented change of rrd base
+}
+
 void KCollectdGui::autoUpdate(bool t) {
   auto_button->setChecked(t);
   auto_action->setChecked(t);
